# scpper

[![PyPI license](https://img.shields.io/pypi/l/scpper.svg)](https://pypi.python.org/pypi/scpper/)
[![PyPI version shields.io](https://img.shields.io/pypi/v/scpper.svg)](https://pypi.python.org/pypi/scpper/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/scpper.svg)](https://pypi.python.org/pypi/scpper/)

**scpper** is a Python wrapper for <a href="https://github.com/FiftyNine/ScpperDB">ScpperDB API</a>.

## Installation

Open console and run the following command:
```
pip install scpper
```
Done.

## Documentation

Detailed information for developers can be found here: http://scpper.readthedocs.org/en/latest/.

## Bugs/Requests

Please use the <a href="https://github.com/skippy-dev/scpper/issues">GitHub issue tracker</a> to submit bugs or request features.

<h2>
Author
</h2>

* <a href="https://github.com/MrNereof">MrNereof</a> - creator of Scpper Python wrapper.
* <a href="https://github.com/FiftyNine">FiftyNine</a> - creator of <a href="https://github.com/FiftyNine/ScpperDB">ScpperDB</a>.